pub struct UpdatePromotionCode { /* private fields */ }Expand description
Updates the specified promotion code by setting the values of the parameters passed. Most fields are, by design, not editable.
Implementations
Sourceimpl UpdatePromotionCode
impl UpdatePromotionCode
Sourcepub fn new(promotion_code: impl Into<PromotionCodeId>) -> Self
pub fn new(promotion_code: impl Into<PromotionCodeId>) -> Self
Construct a new UpdatePromotionCode.
Sourcepub fn active(self, active: impl Into<bool>) -> Self
pub fn active(self, active: impl Into<bool>) -> Self
Whether the promotion code is currently active. A promotion code can only be reactivated when the coupon is still valid and the promotion code is otherwise redeemable.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
Sourcepub fn restrictions(
self,
restrictions: impl Into<UpdatePromotionCodeRestrictions>,
) -> Self
pub fn restrictions( self, restrictions: impl Into<UpdatePromotionCodeRestrictions>, ) -> Self
Settings that restrict the redemption of the promotion code.
Sourceimpl UpdatePromotionCode
impl UpdatePromotionCode
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.