RetrieveTaxCode

Struct RetrieveTaxCode 

pub struct RetrieveTaxCode { /* private fields */ }
Retrieves the details of an existing tax code. Supply the unique tax code ID and Stripe will return the corresponding tax code information.

Implementations

Source

impl RetrieveTaxCode

pub fn new(id: impl Into<TaxCodeId>) -> Self

Construct a new RetrieveTaxCode.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

Source

impl RetrieveTaxCode

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.